@@ -43,9 +43,6 @@ using Real = float;
 
 namespace py = pybind11;
 
-template <class T, class U>
-using pair = std::pair<T, U>;
-
 template <class T>
 using vec = std::vector<T>;
 
@@ -92,37 +89,35 @@ template <int D = 2>
 class BB
 {
 private:
-  std::array<Real, 2 * D> values;
+  Real values[2 * D];
 
 public:
   BB() { clear(); }
 
-  template <typename Iter>
-  BB(const Iter &minima, const Iter &maxima)
+  BB(const Real (&minima)[D], const Real (&maxima)[D])
   {
-    std::array<Real, 2 * D> v;
-    if (unlikely(minima.size() != maxima.size()))
-    {
-      throw std::runtime_error("Invalid size");
-    }
-    const int n = minima.size();
-    if (unlikely(n != D))
-    {
-      throw std::runtime_error("Invalid size");
-    }
-    for (int i = 0; i < n; ++i)
+    Real v[2 * D];
+    for (int i = 0; i < D; ++i)
     {
       v[i] = -minima[i];
       v[i + D] = maxima[i];
     }
     validate(v);
-    values = v;
+    for (int i = 0; i < D; ++i)
+    {
+      values[i] = v[i];
+      values[i + D] = v[i + D];
+    }
   }
 
-  BB(const std::array<Real, 2 * D> v)
+  BB(const Real (&v)[2 * D])
   {
     validate(v);
-    values = v;
+    for (int i = 0; i < D; ++i)
+    {
+      values[i] = v[i];
+      values[i + D] = v[i + D];
+    }
   }
 
   Real min(const int dim) const
@@ -142,7 +137,7 @@ public:
     return values[dim + D];
   }
 
-  bool validate(const std::array<Real, 2 * D> &v) const
+  bool validate(const Real (&v)[2 * D]) const
   {
     bool flag = false;
     for (int i = 0; i < 2; ++i)
@@ -159,11 +154,17 @@ public:
     }
     return flag;
   }
-  void clear() { std::fill_n(values.begin(), 2 * D, -1e100); }
+  void clear()
+  {
+    for (int i = 0; i < 2 * D; ++i)
+    {
+      values[i] = -1e100;
+    }
+  }
 
   BB operator+(const BB &rhs) const
   {
-    std::array<Real, 2 * D> result;
+    Real result[2 * D];
     for (int i = 0; i < 2 * D; ++i)
     {
       result[i] = std::max(values[i], rhs.values[i]);
@@ -180,7 +181,7 @@ public:
     return *this;
   }
 
-  void expand(const std::array<Real, D> &delta)
+  void expand(const Real (&delta)[D])
   {
     for (int i = 0; i < D; ++i)
     {
@@ -192,7 +193,7 @@ public:
   bool operator()(
       const BB &target) const
   { // whether this and target has any intersect
-    std::array<Real, 2 * D> result;
+    Real result[2 * D];
     for (int i = 0; i < 2 * D; ++i)
     {
       result[i] = std::min(values[i], target.values[i]);
@@ -350,7 +351,7 @@ template <class T, int B = 6, int D = 2>
 class PseudoPRTreeNode
 {
 public:
-  std::array<Leaf<T, B, D>, 2 * D> leaves;
+  Leaf<T, B, D> leaves[2 * D];
   std::unique_ptr<PseudoPRTreeNode> left, right;
 
   PseudoPRTreeNode()
@@ -423,6 +424,7 @@ public:
       root = std::make_unique<PseudoPRTreeNode<T, B, D>>();
     }
     construct(root.get(), b, e, 0);
+    clean_data<T, D>(b, e);
   }
 
   template <class Archive>
@@ -496,7 +498,6 @@ public:
     if (cache_children.empty())
     {
       using U = PseudoPRTreeNode<T, B, D>;
-      vec<U *> leaf_nodes;
       cache_children.reserve(hint);
       auto node = root.get();
       queue<U *> que;
@@ -506,7 +507,6 @@ public:
       {
         node = que.front();
         que.pop();
-        leaf_nodes.emplace_back(node);
         node->address_of_leaves(cache_children);
         if (node->left)
           que.emplace(node->left.get());
@@ -517,8 +517,7 @@ public:
     return cache_children;
   }
 
-  std::pair<DataType<T, D> *, DataType<T, D> *> as_X(void *placement,
-                                                     const int hint)
+  std::pair<DataType<T, D> *, DataType<T, D> *> as_X(void *placement, const int hint)
   {
     DataType<T, D> *b, *e;
     auto children = get_all_leaves(hint);
@@ -649,8 +648,8 @@ public:
 
     for (T i = 0; i < length; i++)
     {
-      std::array<Real, D> minima;
-      std::array<Real, D> maxima;
+      Real minima[D];
+      Real maxima[D];
       for (int j = 0; j < D; ++j)
       {
         minima[j] = rx(i, j);
@@ -663,8 +662,8 @@ public:
 
     for (size_t i = 0; i < length; i++)
     {
-      std::array<Real, D> minima;
-      std::array<Real, D> maxima;
+      Real minima[D];
+      Real maxima[D];
       for (int j = 0; j < D; ++j)
       {
         minima[j] = rx(i, j);
@@ -720,8 +719,8 @@ public:
       throw std::runtime_error("Given index is already included.");
     }
     {
-      std::array<Real, D> minima;
-      std::array<Real, D> maxima;
+      Real minima[D];
+      Real maxima[D];
       for (int i = 0; i < D; ++i)
       {
         minima[i] = *x.data(i);
@@ -732,7 +731,7 @@ public:
     idx2bb.emplace(idx, bb);
     set_obj(idx, objdumps);
 
-    std::array<Real, D> delta;
+    Real delta[D];
     for (int i = 0; i < D; ++i)
     {
       delta[i] = bb.max(i) - bb.min(i) + 0.00000001;
@@ -751,7 +750,7 @@ public:
 
     while (likely(cands.size() == 0))
     {
-      std::array<Real, D> d;
+      Real d[D];
       for (int i = 0; i < D; ++i)
       {
         d[i] = delta[i] * c;
@@ -889,7 +888,6 @@ public:
 
     auto first_tree = PseudoPRTree<T, B, D>(b, e);
     auto first_leaves = first_tree.get_all_leaves(e - b);
-    clean_data<T, D>(b, e);
     for (auto &leaf : first_leaves)
     {
       auto pp = std::make_unique<PRTreeNode<T, B, D>>(leaf);
@@ -900,7 +898,6 @@ public:
     {
       auto tree = PseudoPRTree<T, B, D>(bb, ee);
       auto leaves = tree.get_all_leaves(ee - bb);
-      clean_data<T, D>(bb, ee);
       auto leaves_size = leaves.size();
 
       vec<std::unique_ptr<PRTreeNode<T, B, D>>> tmp_nodes;
@@ -988,8 +985,8 @@ public:
     if (ndim == 1)
     {
       {
-        std::array<Real, D> minima;
-        std::array<Real, D> maxima;
+        Real minima[D];
+        Real maxima[D];
         for (int i = 0; i < D; ++i)
         {
           minima[i] = *x.data(i);
@@ -1012,8 +1009,8 @@ public:
       for (long int i = 0; i < shape_x[0]; i++)
       {
         {
-          std::array<Real, D> minima;
-          std::array<Real, D> maxima;
+          Real minima[D];
+          Real maxima[D];
           for (int j = 0; j < D; ++j)
           {
             minima[j] = *x.data(i, j);
@@ -1047,8 +1044,8 @@ public:
     {
       throw std::runtime_error("invalid shape");
     }
-    std::array<Real, D> minima;
-    std::array<Real, D> maxima;
+    Real minima[D];
+    Real maxima[D];
     if (x.size() == D)
     {
       is_point = true;
